@@ -131,7 +131,7 @@ async def sync_elem_discovery(preseem_model,
                 if site:
                     model_sites[site.uuid] = site_names[site_name] = site
 
-        unref_discs = set(model_discs)
+        unref_discs = set([x[0] for x in model_discs.items() if x[1].source == source])
         uuid_map = {}
         for item in items:
             host = str(ipaddress.ip_address(item.host))  # validate ip address
